TypedRule

Trait TypedRule 

pub(super) trait TypedRule:
    Send
    + Sync
    + 'static {
    type Violation: TypedRuleViolation<Rule = Self> + FormattedRuleViolation + 'static;

    // Required methods
    fn code() -> &'static str;
    fn check(&self, ctx: &FileContext<'_>) -> Vec<Self::Violation>;
}
Typed rule contract implemented by each concrete rule.

Keeping the associated violation here prevents a rule from returning the violation type owned by another rule, while still allowing dyn Rule.

Required Associated Types

Required Methods

fn code() -> &'static str

fn check(&self, ctx: &FileContext<'_>) -> Vec<Self::Violation>

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors